==> ntex-0.3.17.crate: ntex-0.3.17/README.md <==
<div align="center">
 <p><h1>ntex</h1> </p>
  <p><strong>Framework for composable network services. This is personal project.</strong> </p>
  <p>

[![build status](https://github.com/ntex-rs/ntex/workflows/CI%20%28Linux%29/badge.svg?branch=master&event=push)](https://github.com/ntex-rs/ntex/actions?query=workflow%3A"CI+(Linux)") 
[![codecov](https://codecov.io/gh/ntex-rs/ntex/branch/master/graph/badge.svg)](https://codecov.io/gh/ntex-rs/ntex) 
[![crates.io](https://meritbadge.herokuapp.com/ntex)](https://crates.io/crates/ntex) 
[![Documentation](https://docs.rs/ntex/badge.svg)](https://docs.rs/ntex) 
[![Version](https://img.shields.io/badge/rustc-1.46+-lightgray.svg)](https://blog.rust-lang.org/2020/08/27/Rust-1.46.0.html) 
![License](https://img.shields.io/crates/l/ntex.svg) 

  </p>
</div>

## Build statuses

| Platform         | Build Status |
| ---------------- | ------------ |
| Linux            | [![build status](https://github.com/ntex-rs/ntex/workflows/CI%20%28Linux%29/badge.svg?branch=master&event=push)](https://github.com/ntex-rs/ntex/actions?query=workflow%3A"CI+(Linux)") |
| macOS            | [![build status](https://github.com/ntex-rs/ntex/workflows/CI%20%28OSX%29/badge.svg?branch=master&event=push)](https://github.com/ntex-rs/ntex/actions?query=workflow%3A"CI+(OSX)") |
| Windows          | [![build status](https://github.com/ntex-rs/ntex/workflows/CI%20%28Windows%29/badge.svg?branch=master&event=push)](https://github.com/ntex-rs/ntex/actions?query=workflow%3A"CI+(Windows)") |

## Documentation & community resources

* [Documentation](https://docs.rs/ntex)
* Minimum supported Rust version: 1.46 or later

## License

This project is licensed under

* MIT license ([LICENSE-MIT](LICENSE-MIT) or [http://opensource.org/licenses/MIT](http://opensource.org/licenses/MIT))

==> ntex-0.4.4.crate: ntex-0.4.4/README.md <==
<div align="center">
 <p><h1>ntex</h1> </p>
  <p><strong>Framework for composable network services. This is personal project. This project uses *unsafe*!</strong> </p>
  <p>

[![build status](https://github.com/ntex-rs/ntex/workflows/CI%20%28Linux%29/badge.svg?branch=master&event=push)](https://github.com/ntex-rs/ntex/actions?query=workflow%3A"CI+(Linux)") 
[![codecov](https://codecov.io/gh/ntex-rs/ntex/branch/master/graph/badge.svg)](https://codecov.io/gh/ntex-rs/ntex) 
[![crates.io](https://img.shields.io/crates/v/ntex.svg)](https://crates.io/crates/ntex) 
[![Documentation](https://docs.rs/ntex/badge.svg)](https://docs.rs/ntex) 
[![Version](https://img.shields.io/badge/rustc-1.51+-lightgray.svg)](https://blog.rust-lang.org/2021/03/25/Rust-1.51.0.html) 
![License](https://img.shields.io/crates/l/ntex.svg) 

  </p>
</div>

## Build statuses

| Platform         | Build Status |
| ---------------- | ------------ |
| Linux            | [![build status](https://github.com/ntex-rs/ntex/workflows/CI%20%28Linux%29/badge.svg?branch=master&event=push)](https://github.com/ntex-rs/ntex/actions?query=workflow%3A"CI+(Linux)") |
| macOS            | [![build status](https://github.com/ntex-rs/ntex/workflows/CI%20%28OSX%29/badge.svg?branch=master&event=push)](https://github.com/ntex-rs/ntex/actions?query=workflow%3A"CI+(OSX)") |
| Windows          | [![build status](https://github.com/ntex-rs/ntex/workflows/CI%20%28Windows%29/badge.svg?branch=master&event=push)](https://github.com/ntex-rs/ntex/actions?query=workflow%3A"CI+(Windows)") |

## Documentation & community resources

* [Documentation](https://docs.rs/ntex)
* Minimum supported Rust version: 1.48 or later

## License

This project is licensed under

* MIT license ([LICENSE](LICENSE) or [http://opensource.org/licenses/MIT](http://opensource.org/licenses/MIT))
